==> atmosphere-rest-twitter-0.3-sources.jar: org/atmosphere/samples/twitter/TwitterBroadcaster.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package org.atmosphere.samples.twitter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.atmosphere.core.JerseyBroadcaster;
import org.atmosphere.cpr.AtmosphereEvent;
import org.atmosphere.cpr.Broadcaster;

/**
 * Simple {@link Broadcaster} that keep a reference to the user {@ link AtmosphereEvent}
 * 
 * @author Jeanfrancois Arcand
 */
public class TwitterBroadcaster extends JerseyBroadcaster{

    private AtmosphereEvent event;

    /**
     * Set the user (@link Broadcaster#getName}'s AtmosphereEvent.
     * @param event AtmosphereEvent
     */
    public void setUserAtmosphereEvent(AtmosphereEvent event){
        this.event = event;
    }

    /**
     * Return the user (@link Broadcaster#getName}'s AtmosphereEvent.
     * @return event AtmosphereEvent
     */
    public AtmosphereEvent<HttpServletRequest,HttpServletResponse> getUserAtmosphereEvent(){
        return event;
    }

    @Override
    public AtmosphereEvent<HttpServletRequest,HttpServletResponse>
            addAtmosphereEvent(AtmosphereEvent<HttpServletRequest,HttpServletResponse> e) {
        if (events.size() == 0){
            event = e;
        }
        return super.addAtmosphereEvent(e);
    }
}

==> atmosphere-rest-twitter-0.5.3-sources.jar: org/atmosphere/samples/twitter/TwitterBroadcaster.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package org.atmosphere.samples.twitter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.atmosphere.jersey.JerseyBroadcaster;
import org.atmosphere.cpr.AtmosphereResource;
import org.atmosphere.cpr.AtmosphereResourceEvent;
import org.atmosphere.cpr.AtmosphereResourceImpl;
import org.atmosphere.cpr.Broadcaster;

/**
 * Simple {@link Broadcaster} that keep a reference to the user {@ link AtmosphereResourceEvent}
 * 
 * @author Jeanfrancois Arcand
 */
public class TwitterBroadcaster extends JerseyBroadcaster{

    private AtmosphereResourceEvent event;

    /**
     * Set the user (@link Broadcaster#getName}'s AtmosphereResourceEvent.
     * @param event AtmosphereResourceEvent
     */
    public void setUserAtmosphereEvent(AtmosphereResourceEvent event){
        this.event = event;
    }

    /**
     * Return the user (@link Broadcaster#getName}'s AtmosphereResourceEvent.
     * @return event AtmosphereResourceEvent
     */
    public AtmosphereResourceEvent<HttpServletRequest,HttpServletResponse> getUserAtmosphereEvent(){
        return event;
    }

    @Override
    public AtmosphereResource addAtmosphereResource(AtmosphereResource r) {
        if (events.size() == 0){
            if (r instanceof AtmosphereResourceImpl){
                event = ((AtmosphereResourceImpl)r).event();
            }
        }
        return super.addAtmosphereResource(r);
    }
}
